
# Slot: precedes


holds between two processes, where one completes before the other begins

URI: [biolink:precedes](https://w3id.org/biolink/vocab/precedes)

## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [ActivityAndBehavior](ActivityAndBehavior.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [MolecularActivity](MolecularActivity.md)
 * [Occurrent](Occurrent.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [Procedure](Procedure.md)
